@@ -45,15 +45,16 @@ function(y, m, n=length(y), N=Inf, level=0.95){
     hynv.anteil <- c(ugrh,ogrh)
     hynv.anzahl = c(ceiling(ugrh*N),floor(ogrh*N))
   #exact procedure
-    #lower border: start with smallest possible value (number 1 in sample)
+    # lower border: start with smallest possible value (number 1 in sample)
     ugrex <- m
-    #checkup if condition is complied with
+    # while prob fct for lower bound is larger than 1-alpha/2 (from 1-prob fct)
     while (phyper(m-1,ugrex,N-ugrex,n)>(level+1)/2) { ugrex=ugrex+1 } 
-    ugrex= max(m,ugrex-1)                                                                                 
+    ugrex = ugrex-1
     #upper border: total number - number 0 in sample
     ogrex=N-(n-m)
+    # while prob fct for upper bound is smaller than alpha/2
     while (phyper(m,ogrex,N-ogrex,n) < (1-level)/2) { ogrex=ogrex-1 }
-    ogrex = min(N-(n-m), ogrex+1)
+    ogrex = ogrex+1
     exact.anteil = c(ugrex/N, ogrex/N)
     exact.anzahl = c(ugrex, ogrex)
   }
